@@ -103,13 +103,13 @@ def OpenMageWindow ():
 		Button = Window.GetControl (3 + i)
 		Button.SetBorder (0,0,0,0,0,0,0,0,64,0,1)
 		Button.SetSprites ("SPELFRAM",0,0,0,0,0)
-		Button.SetFlags (IE_GUI_BUTTON_PICTURE, OP_OR)
+		Button.SetFlags (IE_GUI_BUTTON_PICTURE | IE_GUI_BUTTON_PLAYONCE, OP_OR)
 		Button.SetState (IE_GUI_BUTTON_LOCKED)
 
 	# Setup book spells buttons
 	for i in range (GUICommon.GetIWDSpellButtonCount()):
 		Button = Window.GetControl (27 + i)
-		Button.SetFlags (IE_GUI_BUTTON_NO_IMAGE, OP_OR)
+		Button.SetFlags (IE_GUI_BUTTON_NO_IMAGE | IE_GUI_BUTTON_PLAYONCE, OP_OR)
 		Button.SetState (IE_GUI_BUTTON_LOCKED)
 
 	GUICommonWindows.SetSelectionChangeHandler (UpdateMageWindow)
@@ -139,14 +139,14 @@ def UpdateMageWindow ():
 	Name = GemRB.GetPlayerName (pc, 0)
 	Label = Window.GetControl (0x10000035)
 	Label.SetText (Name)
-	mem_cnt = GemRB.GetMemorizedSpellsCount (pc, type, level)
+	mem_cnt = GemRB.GetMemorizedSpellsCount (pc, type, level, False)
 	for i in range (12):
 		Button = Window.GetControl (3 + i)
 		if i < mem_cnt:
 			ms = GemRB.GetMemorizedSpell (pc, type, level, i)
 			Button.SetSpellIcon (ms['SpellResRef'], 0)
 			Button.SetFlags (IE_GUI_BUTTON_NO_IMAGE, OP_NAND)
-			Button.SetFlags (IE_GUI_BUTTON_PICTURE, OP_OR)
+			Button.SetFlags (IE_GUI_BUTTON_PICTURE | IE_GUI_BUTTON_PLAYONCE, OP_OR)
 			if ms['Flags']:
 				Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, OpenMageSpellUnmemorizeWindow)
 			else:
@@ -159,7 +159,7 @@ def UpdateMageWindow ():
 			Button.EnableBorder (0, ms['Flags'] == 0)
 		else:
 			if i < max_mem_cnt:
-				Button.SetFlags (IE_GUI_BUTTON_NORMAL, OP_SET)
+				Button.SetFlags (IE_GUI_BUTTON_NORMAL | IE_GUI_BUTTON_PLAYONCE, OP_SET)
 			else:
 				Button.SetFlags (IE_GUI_BUTTON_NO_IMAGE, OP_SET)
 			Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, None)
@@ -227,6 +227,12 @@ def OnMageMemorizeSpell ():
 
 	if GemRB.MemorizeSpell (pc, type, level, index):
 		UpdateMageWindow ()
+		GemRB.PlaySound ("GAM_24")
+		Button = MageWindow.GetControl(index + 27)
+		Button.SetAnimation ("FLASH",0,1)
+		mem_cnt = GemRB.GetMemorizedSpellsCount (pc, type, level, False)
+		Button = MageWindow.GetControl(mem_cnt + 2)
+		Button.SetAnimation ("FLASH",0,1)
 	return
 
 def OpenMageSpellInfoWindow ():
@@ -335,6 +341,9 @@ def OnMageUnmemorizeSpell ():
 
 	if GemRB.UnmemorizeSpell (pc, type, level, index):
 		UpdateMageWindow ()
+		GemRB.PlaySound ("GAM_44")
+		Button = MageWindow.GetControl(index + 3)
+		Button.SetAnimation ("FLASH",0,1)
 	return
 
 def OnMageRemoveSpell ():
