@@ -21,6 +21,9 @@
 #include "GUI/Button.h"
 
 #include "GUI/GameControl.h"
+#include "GUI/EventMgr.h"
+#include "GUI/ScrollBar.h"
+#include "GUI/Window.h"
 
 #include "defsounds.h"
 #include "win32def.h"
@@ -125,7 +128,7 @@ void Button::CloseUpColor()
 	unsigned long newtime;
 
 	Changed = true;
-	GetTime( newtime );
+	newtime = GetTickCount();
 	if (newtime<starttime) {
 		return;
 	}
@@ -410,13 +413,11 @@ void Button::OnMouseDown(unsigned short x, unsigned short y,
 	case GEM_MB_SCRLUP:
 		if (scrlbr) {
 			scrlbr->ScrollUp();
-			core->RedrawAll();
 		}
 		break; 
 	case GEM_MB_SCRLDOWN:
 		if (scrlbr) {
 			scrlbr->ScrollDown();
-			core->RedrawAll();
 		}
 		break;
 	}
@@ -504,6 +505,21 @@ void Button::OnMouseUp(unsigned short x, unsigned short y,
 	}
 }
 
+void Button::OnMouseWheelScroll(short x, short y)
+{
+	ScrollBar* scrlbr = (ScrollBar*) sb;
+	if (!scrlbr) {
+		Control *ctrl = Owner->GetScrollControl();
+		if (ctrl && (ctrl->ControlType == IE_GUI_SCROLLBAR)) {
+			scrlbr = (ScrollBar *) ctrl;
+		}
+	}
+	
+	if (scrlbr) {
+		scrlbr->OnMouseWheelScroll(x, y);
+	}
+}
+
 void Button::OnMouseOver(unsigned short x, unsigned short y)
 {
 	Owner->Cursor = IE_CURSOR_NORMAL;
@@ -572,7 +588,7 @@ void Button::OnMouseLeave(unsigned short /*x*/, unsigned short /*y*/)
 
 
 /** Sets the Text of the current control */
-int Button::SetText(const char* string, int /*pos*/)
+void Button::SetText(const char* string)
 {
 	free(Text);
 	Text = NULL;
@@ -589,7 +605,6 @@ int Button::SetText(const char* string, int /*pos*/)
 		hasText = true;
 	}
 	Changed = true;
-	return 0;
 }
 
 /** Set Event Handler */
@@ -713,7 +728,7 @@ void Button::SetHorizontalOverlay(double clip, const Color &src, const Color &de
 		Flags |= IE_GUI_BUTTON_HORIZONTAL;
 		SourceRGB=src;
 		DestRGB=dest;
-		GetTime( starttime );
+		starttime = GetTickCount();
 		starttime += 40;
 	}
 	Clipping = clip;
