@@ -26,11 +26,12 @@
 
 #include "Interface.h"
 #include "Video.h"
-#include "EventMgr.h"
+#include "GUI/Window.h"
+//N900
 #include <iostream>
 #include <fstream>
 using namespace std;
-
+//
 EventMgr::EventMgr(void)
 {
 	last_win_focused = NULL;
@@ -45,6 +46,7 @@ EventMgr::EventMgr(void)
 	dc_delay = 250;
 	rk_delay = 250;
 	rk_flags = GEM_RK_DISABLE;
+	//N900 - NerdKnight
 	fakeRMB=false;
         proximitySensorEnabled=true;
         rmbk='x';
@@ -54,28 +56,6 @@ EventMgr::~EventMgr(void)
 {
 }
 
-bool EventMgr::isProximitySensorClosed()
-{
-	bool res=false;
-        if(proximitySensorEnabled){
-            ifstream::pos_type size;
-            char * memblock;
-            ifstream file ("/sys/devices/platform/gpio-switch/proximity/state", ios::in|ios::binary|ios::ate);
-            //ifstream file ("/home/maemo/workspace/state", ios::in|ios::binary|ios::ate);
-            if (file.is_open())
-            {
-                    size = file.tellg();
-                    memblock = new char [size];
-                    file.seekg (0, ios::beg);
-                    file.read (memblock, size);
-                    file.close();
-                    res=(memblock[0]=='c');
-                    delete[] memblock;
-            }
-        }
-	return res;
-}
-
 void EventMgr::SetOnTop(int Index)
 {
 	std::vector< int>::iterator t;
@@ -256,25 +236,18 @@ bool EventMgr::ClickMatch(unsigned short x, unsigned short y, unsigned long this
 	return true;
 }
 
-unsigned short EventMgr::getFakeButton(unsigned short Button)
-{
-	unsigned short res=Button;
-	if(fakeRMB||isProximitySensorClosed())
-		res=GEM_MB_MENU;
-	return res;
-}
-
 /** BroadCast Mouse Move Event */
 void EventMgr::MouseDown(unsigned short x, unsigned short y, unsigned short Button,
 	unsigned short Mod)
 {
+	//N900
 	Button=getFakeButton(Button);
 	std::vector< int>::iterator t;
 	std::vector< Window*>::iterator m;
 	Control *ctrl;
 	unsigned long thisTime;
 
-	GetTime( thisTime );
+	thisTime = GetTickCount();
 	if (ClickMatch(x, y, thisTime)) {
 		Button |= GEM_MB_DOUBLECLICK;
 		dc_x = 0;
@@ -314,7 +287,7 @@ void EventMgr::MouseDown(unsigned short x, unsigned short y, unsigned short Butt
 		if (( *m )->Visible == WINDOW_FRONT) //stop looking further
 			break;
 	}
-
+	
 	if ((Button == GEM_MB_SCRLUP || Button == GEM_MB_SCRLDOWN) && last_win_mousefocused) {
 		ctrl = last_win_mousefocused->GetScrollControl();
 		if (ctrl) {
@@ -326,10 +299,12 @@ void EventMgr::MouseDown(unsigned short x, unsigned short y, unsigned short Butt
 		last_win_mousefocused->SetMouseFocused(NULL);
 	}
 }
+
 /** BroadCast Mouse Up Event */
 void EventMgr::MouseUp(unsigned short x, unsigned short y, unsigned short Button,
 	unsigned short Mod)
 {
+	//N900
 	Button=getFakeButton(Button);
 	MButtons &= ~Button;
 	if (last_win_mousefocused == NULL) return;
@@ -339,6 +314,18 @@ void EventMgr::MouseUp(unsigned short x, unsigned short y, unsigned short Button
 		y - last_win_mousefocused->YPos - last_ctrl_mousefocused->YPos, Button, Mod );
 }
 
+/** BroadCast Mouse ScrollWheel Event */
+void EventMgr::MouseWheelScroll( short x, short y)//these are signed!
+{
+	if (last_win_mousefocused) {
+		Control *ctrl;
+		ctrl = last_win_mousefocused->GetFocus();
+		if (ctrl) {
+			ctrl->OnMouseWheelScroll( x, y);
+		}
+	}
+}
+
 /** BroadCast Mouse Idle Event */
 void EventMgr::MouseIdle(unsigned long /*time*/)
 {
@@ -351,8 +338,10 @@ void EventMgr::MouseIdle(unsigned long /*time*/)
 /** BroadCast Key Press Event */
 void EventMgr::KeyPress(unsigned char Key, unsigned short Mod)
 {
+	//N900
 	if(Key==rmbk)
-			fakeRMB=true;
+		fakeRMB=true;
+	//
 	if (last_win_focused == NULL) return;
 	Control *ctrl = last_win_focused->GetFocus();
 	if (ctrl == NULL) return;
@@ -361,8 +350,10 @@ void EventMgr::KeyPress(unsigned char Key, unsigned short Mod)
 /** BroadCast Key Release Event */
 void EventMgr::KeyRelease(unsigned char Key, unsigned short Mod)
 {
+	//N900
 	if(Key==rmbk)
 		fakeRMB=false;
+	//
 	if (last_win_focused == NULL) return;
 	Control *ctrl = last_win_focused->GetFocus();
 	if (Key == GEM_GRAB) {
@@ -424,6 +415,7 @@ void EventMgr::OnSpecialKeyPress(unsigned char Key)
 				}
 				break;
 			case IE_GUI_GAMECONTROL:
+			case IE_GUI_WORLDMAP:
 				//gamecontrols will receive all special keys
 				break;
 			case IE_GUI_EDIT:
@@ -480,3 +472,33 @@ unsigned long EventMgr::SetRKFlags(unsigned long arg, unsigned int op)
 	rk_flags=tmp;
 	return rk_flags;
 }
+/*N900 - NerdKnight*/
+bool EventMgr::isProximitySensorClosed()
+{
+	bool res=false;
+        if(proximitySensorEnabled){
+            ifstream::pos_type size;
+            char * memblock;
+            ifstream file ("/sys/devices/platform/gpio-switch/proximity/state", ios::in|ios::binary|ios::ate);
+            //ifstream file ("/home/maemo/workspace/state", ios::in|ios::binary|ios::ate);
+            if (file.is_open())
+            {
+                    size = file.tellg();
+                    memblock = new char [size];
+                    file.seekg (0, ios::beg);
+                    file.read (memblock, size);
+                    file.close();
+                    res=(memblock[0]=='c');
+                    delete[] memblock;
+            }
+        }
+	return res;
+}
+/*N900 - NerdKnight*/
+unsigned short EventMgr::getFakeButton(unsigned short Button)
+{
+	unsigned short res=Button;
+	if(fakeRMB||isProximitySensorClosed())
+		res=GEM_MB_MENU;
+	return res;
+}
