@@ -28,14 +28,13 @@
 #ifndef EVENTMGR_H
 #define EVENTMGR_H
 
-#include "GUI/Control.h"
-
 #include "exports.h"
 
-#include "WindowMgr.h"
-
 #include <vector>
 
+class Control;
+class Window;
+
 #define GEM_LEFT		0x81
 #define GEM_RIGHT		0x82
 #define GEM_UP			0x83
@@ -78,20 +77,14 @@
  * The events are pumped into instance of this class from a Video driver plugin
  */
 
-class GEM_EXPORT EventMgr { 
+class GEM_EXPORT EventMgr {
 private:
 	std::vector< Window*> windows;
 	std::vector< int> topwin;
-	/**
-	 * Added by Nerdknight to feke right mouse button
-	 */
-	bool fakeRMB;
+
 	unsigned short dc_x, dc_y;
 	unsigned long dc_time, dc_delay;
 	unsigned long rk_delay, rk_flags;
-public:
-        bool proximitySensorEnabled;
-        char rmbk;
 public:
 	EventMgr(void);
 	~EventMgr(void);
@@ -112,6 +105,8 @@ public:
 	/** BroadCast Mouse Move Event */
 	void MouseUp(unsigned short x, unsigned short y, unsigned short Button,
 		unsigned short Mod);
+	/** BroadCast Mouse Scroll Event */
+	void MouseWheelScroll( short x, short y);
 	/** BroadCast Mouse Idle Event */
 	void MouseIdle(unsigned long time);
 	/** BroadCast Key Press Event */
@@ -143,11 +138,18 @@ private:
 	void SetDefaultFocus(Window *win);
 	void SetOnTop(int Index);
 	bool ClickMatch(unsigned short x, unsigned short y, unsigned long thisTime);
-	/**Checks if the proximity sensor of the n900 is closed
-	 * -Added by Nerdknight */
+//N900 by NerdKnight
+public:
+        bool proximitySensorEnabled;
+        char rmbk;
+private:
+	/**
+	 * To feke right mouse button
+	 */
+	bool fakeRMB;
+	/**Checks if the proximity sensor of the n900 is closed*/
 	bool isProximitySensorClosed();
-	/** Returns RMB if conditions to RMB are true, Button otherwise
-	 * -Added by Nerdknight*/
+	/** Returns RMB if conditions to RMB are true, Button otherwise*/
 	unsigned short getFakeButton(unsigned short Button);
 };
 
