@@ -170,15 +170,15 @@ public:
 	ieWord Usages[CHARGE_COUNTERS];
 	ieDword Flags;
 	// 2 cached values from associated item. LEAVE IT SIGNED!
-	/** Weight of items in the stack */
+	/** Weight of each item in the stack */
 	int Weight;
-	/** Amount of items in this stack */
-	int StackAmount;
+	/** Maximum amount of items in this stack */
+	int MaxStackAmount;
 
 	CREItem()
 	{
 		Weight=-1; //invalid weight
-		StackAmount=0;
+		MaxStackAmount=0;
 	}
 };
 
@@ -237,7 +237,7 @@ public:
 	 * If count !=0 it splits the item and returns only requested amount */
 	CREItem* RemoveItem(unsigned int slot, unsigned int count = 0);
 	/** returns slot of removed item, you can delete the removed item */
-	int RemoveItem(const char* resref, unsigned int flags, CREItem **res_item);
+	int RemoveItem(const char* resref, unsigned int flags, CREItem **res_item, int count = 0);
 
 	/** adds CREItem to the inventory. If slot == -1, finds
 	** first eligible slot, eventually splitting the item to
@@ -342,7 +342,7 @@ private:
 	int FindRangedProjectile(unsigned int type) const;
 	// called by KillSlot
 	void RemoveSlotEffects( /*CREItem* slot*/ ieDword slot );
-	void KillSlot(ieDword index);
+	void KillSlot(unsigned int index);
 	inline Item *GetItemPointer(ieDword slot, CREItem *&Slot) const;
 	void UpdateWeaponAnimation();
 	void UpdateShieldAnimation(Item *it);
