@@ -196,6 +196,8 @@
 #define STR_WILDSURGE     163
 #define STR_FAMBLOCK      164
 #define STR_FAMPROTAGONIST 165
-#define STRREF_COUNT 166
+#define STR_MAGIC_RESISTED 166
+#define STR_CANTSAVESTORE 167
+#define STRREF_COUNT 168
 
 #endif //! IE_STRINGS_H
