@@ -33,15 +33,17 @@
 #include "ImageMgr.h"
 #include "Interface.h"
 #include "Palette.h"
+#include "PluginMgr.h"
 #include "ProjectileServer.h"
 #include "TileMapMgr.h"
 #include "Video.h"
 #include "GameScript/GameScript.h"
+#include "GUI/Window.h"
 #include "Scriptable/Container.h"
 #include "Scriptable/Door.h"
 #include "Scriptable/InfoPoint.h"
-#include "System/CachedFileStream.h"
 #include "System/FileStream.h"
+#include "System/SlicedStream.h"
 
 #define DEF_OPEN   0
 #define DEF_CLOSE  1
@@ -70,7 +72,7 @@ Holder<DataFileMgr> INInote;
 ResRefToStrRef *tracks = NULL;
 int trackcount = 0;
 
-void ReleaseMemory()
+static void ReleaseMemory()
 {
 	INInote.release();
 
@@ -78,17 +80,16 @@ void ReleaseMemory()
 	tracks = NULL;
 }
 
-void ReadAutonoteINI()
+static void ReadAutonoteINI()
 {
 	INInote = PluginHolder<DataFileMgr>(IE_INI_CLASS_ID);
-	FileStream* fs = new FileStream();
 	char tINInote[_MAX_PATH];
 	PathJoin( tINInote, core->GamePath, "autonote.ini", NULL );
-	fs->Open( tINInote, true );
-	INInote->Open( fs, true );
+	FileStream* fs = FileStream::OpenFile( tINInote );
+	INInote->Open(fs);
 }
 
-int GetTrackString(const ieResRef areaName)
+static int GetTrackString(const ieResRef areaName)
 {
 	int i;
 	bool trackflag = displaymsg->HasStringReference(STR_TRACKING);
@@ -123,7 +124,6 @@ int GetTrackString(const ieResRef areaName)
 
 AREImporter::AREImporter(void)
 {
-	autoFree = false;
 	str = NULL;
 	if (Sounds[0][0] == UNINITIALIZED_BYTE) {
 		memset( Sounds, 0, sizeof( Sounds ) );
@@ -141,22 +141,17 @@ AREImporter::AREImporter(void)
 
 AREImporter::~AREImporter(void)
 {
-	if (autoFree) {
-		delete str;
-	}
+	delete str;
 	Sounds[0][0]=UNINITIALIZED_BYTE;
 }
 
-bool AREImporter::Open(DataStream* stream, bool autoFree)
+bool AREImporter::Open(DataStream* stream)
 {
 	if (stream == NULL) {
 		return false;
 	}
-	if (this->autoFree) {
-		delete str;
-	}
+	delete str;
 	str = stream;
-	this->autoFree = autoFree;
 	char Signature[8];
 	str->Read( Signature, 8 );
 
@@ -253,7 +248,7 @@ bool AREImporter::ChangeMap(Map *map, bool day_or_night)
 	}
 	tm = tmm->GetTileMap(tm);
 	if (!tm) {
-		printf( "[AREImporter]: No Tile Map Available.\n" );
+		print( "[AREImporter]: No Tile Map Available.\n" );
 		return false;
 	}
 
@@ -273,7 +268,7 @@ bool AREImporter::ChangeMap(Map *map, bool day_or_night)
 
 	ResourceHolder<ImageMgr> lm(TmpResRef);
 	if (!lm) {
-		printf( "[AREImporter]: No lightmap available.\n" );
+		print( "[AREImporter]: No lightmap available.\n" );
 		return false;
 	}
 
@@ -292,8 +287,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 
 	Map* map = new Map();
 	if(!map) {
-		printf("Can't allocate map (out of memory).\n");
-		abort();
+		error("AREImporter", "Can't allocate map (out of memory).\n");
 	}
 	if (core->SaveAsOriginal) {
 		map->version = bigheader;
@@ -321,7 +315,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 
 	if (!core->IsAvailable( IE_WED_CLASS_ID )) {
-		printf( "[AREImporter]: No Tile Map Manager Available.\n" );
+		print( "[AREImporter]: No Tile Map Manager Available.\n" );
 		return NULL;
 	}
 	ieResRef TmpResRef;
@@ -339,7 +333,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	//there was no tilemap set yet, so lets just send a NULL
 	TileMap* tm = tmm->GetTileMap(NULL);
 	if (!tm) {
-		printf( "[AREImporter]: No Tile Map Available.\n" );
+		print( "[AREImporter]: No Tile Map Available.\n" );
 		return NULL;
 	}
 
@@ -368,7 +362,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 
 	ResourceHolder<ImageMgr> lm(TmpResRef);
 	if (!lm) {
-		printf( "[AREImporter]: No lightmap available.\n" );
+		print( "[AREImporter]: No lightmap available.\n" );
 		return NULL;
 	}
 
@@ -376,7 +370,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 
 	ResourceHolder<ImageMgr> sr(TmpResRef);
 	if (!sr) {
-		printf( "[AREImporter]: No searchmap available.\n" );
+		print( "[AREImporter]: No searchmap available.\n" );
 		return NULL;
 	}
 
@@ -384,7 +378,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 
 	ResourceHolder<ImageMgr> hm(TmpResRef);
 	if (!hm) {
-		printf( "[AREImporter]: No heightmap available.\n" );
+		print( "[AREImporter]: No heightmap available.\n" );
 		return NULL;
 	}
 
@@ -415,7 +409,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	str->ReadWord( &map->RestHeader.DayChance );
 	str->ReadWord( &map->RestHeader.NightChance );
 
-	printf( "Loading regions\n" );
+	print( "Loading regions\n" );
 	core->LoadProgress(70);
 	//Loading InfoPoints
 	for (i = 0; i < InfoPointsCount; i++) {
@@ -523,7 +517,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		}
 	}
 
-	printf( "Loading containers\n" );
+	print( "Loading containers\n" );
 	//Loading Containers
 	for (i = 0; i < ContainersCount; i++) {
 		str->Seek( ContainersOffset + ( i * 0xC0 ), GEM_STREAM_START );
@@ -630,7 +624,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		c->OpenFail = OpenFail;
 	}
 
-	printf( "Loading doors\n" );
+	print( "Loading doors\n" );
 	//Loading Doors
 	for (i = 0; i < DoorsCount; i++) {
 		str->Seek( DoorsOffset + ( i * 0xc8 ), GEM_STREAM_START );
@@ -833,7 +827,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		door->SetDialog(Dialog);
 	}
 
-	printf( "Loading spawnpoints\n" );
+	print( "Loading spawnpoints\n" );
 	//Loading SpawnPoints
 	for (i = 0; i < SpawnCount; i++) {
 		str->Seek( SpawnOffset + (i*0xc8), GEM_STREAM_START );
@@ -888,11 +882,11 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 
 	core->LoadProgress(75);
-	printf( "Loading actors\n" );
+	print( "Loading actors\n" );
 	//Loading Actors
 	str->Seek( ActorOffset, GEM_STREAM_START );
 	if (!core->IsAvailable( IE_CRE_CLASS_ID )) {
-		printf( "[AREImporter]: No Actor Manager Available, skipping actors\n" );
+		print( "[AREImporter]: No Actor Manager Available, skipping actors\n" );
 	} else {
 		PluginHolder<ActorMgr> actmgr(IE_CRE_CLASS_ID);
 		for (i = 0; i < ActorCount; i++) {
@@ -943,13 +937,12 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 			//actually, Flags&1 signs that the creature
 			//is not loaded yet, so !(Flags&1) means it is embedded
 			if (CreOffset != 0 && !(Flags&1) ) {
-				CachedFileStream *fs = new CachedFileStream( (CachedFileStream *) str, CreOffset, CreSize, true);
-				crefile = (DataStream *) fs;
+				crefile = SliceStream( str, CreOffset, CreSize, true );
 			} else {
 				crefile = gamedata->GetResource( CreResRef, IE_CRE_CLASS_ID );
 			}
-			if(!actmgr->Open( crefile, true )) {
-				printf("Couldn't read actor: %s!\n", CreResRef);
+			if(!actmgr->Open(crefile)) {
+				print("Couldn't read actor: %s!\n", CreResRef);
 				continue;
 			}
 			ab = actmgr->GetActor(0);
@@ -984,11 +977,11 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 
 	core->LoadProgress(90);
-	printf( "Loading animations\n" );
+	print( "Loading animations\n" );
 	//Loading Animations
 	str->Seek( AnimOffset, GEM_STREAM_START );
 	if (!core->IsAvailable( IE_BAM_CLASS_ID )) {
-		printf( "[AREImporter]: No Animation Manager Available, skipping animations\n" );
+		print( "[AREImporter]: No Animation Manager Available, skipping animations\n" );
 	} else {
 		for (i = 0; i < AnimCount; i++) {
 			AreaAnimation* anim = new AreaAnimation();
@@ -1023,7 +1016,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		}
 	}
 
-	printf( "Loading entrances\n" );
+	print( "Loading entrances\n" );
 	//Loading Entrances
 	str->Seek( EntrancesOffset, GEM_STREAM_START );
 	for (i = 0; i < EntrancesCount; i++) {
@@ -1038,7 +1031,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		map->AddEntrance( Name, XPos, YPos, Face );
 	}
 
-	printf( "Loading variables\n" );
+	print( "Loading variables\n" );
 	map->locals->LoadInitialValues(ResRef);
 	//Loading Variables
 	str->Seek( VariablesOffset, GEM_STREAM_START );
@@ -1053,7 +1046,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		map->locals->SetAt( Name, Value );
 	}
 
-	printf( "Loading ambients\n" );
+	print( "Loading ambients\n" );
 	str->Seek( AmbiOffset, GEM_STREAM_START );
 	for (i = 0; i < AmbiCount; i++) {
 		int j;
@@ -1093,7 +1086,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		map->AddAmbient(ambi);
 	}
 
-	printf( "Loading automap notes\n" );
+	print( "Loading automap notes\n" );
 	str->Seek( NoteOffset, GEM_STREAM_START );
 
 	//this feature exists in all blackisle games but not in bioware games
@@ -1168,7 +1161,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 
 	//this is a ToB feature (saves the unexploded projectiles)
-	printf( "Loading traps\n" );
+	print( "Loading traps\n" );
 	for (i = 0; i < TrapCount; i++) {
 		ieResRef TrapResRef;
 		ieDword TrapEffOffset;
@@ -1193,8 +1186,8 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		str->Read( &Owner,1 );
 		int TrapEffectCount = TrapSize/0x108;
 		if(TrapEffectCount*0x108!=TrapSize) {
-			printMessage("AREImporter", " ", LIGHT_RED);
-			printf("TrapEffectSize in game: %d != %d. Clearing it\n", TrapSize, TrapEffectCount*0x108);
+			printMessage("AREImporter", "TrapEffectSize in game: %d != %d. Clearing it\n", LIGHT_RED,
+				TrapSize, TrapEffectCount*0x108);
 				continue;
 		}
 		//The projectile is always created, the worst that can happen
@@ -1205,7 +1198,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 
 		//This could be wrong on msvc7 with its separate memory managers
 		EffectQueue *fxqueue = new EffectQueue();
-		CachedFileStream *fs = new CachedFileStream( (CachedFileStream *) str, TrapEffOffset, TrapSize, true);
+		DataStream *fs = new SlicedStream( str, TrapEffOffset, TrapSize);
 
 		ReadEffects((DataStream *) fs,fxqueue, TrapEffectCount);
 		Actor * caster = core->GetGame()->FindPC(PartyID);
@@ -1218,7 +1211,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		map->AddProjectile( pro, pos, pos);
 	}
 
-	printf( "Loading tiles\n" );
+	print( "Loading tiles\n" );
 	//Loading Tiled objects (if any)
 	str->Seek( TileOffset, GEM_STREAM_START );
 	for (i = 0; i < TileCount; i++) {
@@ -1241,7 +1234,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 		map->TMap->AddTile( ID, Name, Flags, NULL,0, NULL, 0 );
 	}
 
-	printf( "Loading explored bitmap\n" );
+	print( "Loading explored bitmap\n" );
 	i = map->GetExploredMapSize();
 	if (ExploredBitmapSize==i) {
 		map->ExploredBitmap = (ieByte *) malloc(i);
@@ -1250,15 +1243,15 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 	}
 	else {
 		if( ExploredBitmapSize ) {
-			printMessage("AREImporter", " ", LIGHT_RED);
-			printf("ExploredBitmapSize in game: %d != %d. Clearing it\n", ExploredBitmapSize, i);
+			printMessage("AREImporter", "ExploredBitmapSize in game: %d != %d. Clearing it\n", LIGHT_RED,
+				ExploredBitmapSize, i);
 		}
 		ExploredBitmapSize = i;
 		map->ExploredBitmap = (ieByte *) calloc(i, 1);
 	}
 	map->VisibleBitmap = (ieByte *) calloc(i, 1);
 
-	printf( "Loading wallgroups\n");
+	print( "Loading wallgroups\n");
 	map->SetWallGroups( tmm->GetPolygonsCount(),tmm->GetWallGroups() );
 	//setting up doors
 	for (i=0;i<DoorsCount;i++) {
@@ -1273,7 +1266,7 @@ void AREImporter::ReadEffects(DataStream *ds, EffectQueue *fxqueue, ieDword Effe
 	unsigned int i;
 
 	PluginHolder<EffectMgr> eM(IE_EFF_CLASS_ID);
-	eM->Open( ds, true );
+	eM->Open(ds);
 
 	for (i = 0; i < EffectsCount; i++) {
 		Effect fx;
