@@ -52,7 +52,7 @@ public:
 	/** Load Script */
 	bool LoadScript(const char* filename);
 	/** Run Function */
-	bool RunFunction(const char *module, const char* fname, bool error=true, int intparam=-1);
+	bool RunFunction(const char *module, const char* fname, bool report_error=true, int intparam=-1);
 	/** Exec a single File */
 	void ExecFile(const char* file);
 	/** Exec a single String */
